# pyClim

## A Python module to plot climatological data

![Getting Started](./docs/pyClim_logo.png)

pyClim is a Python package that makes analysing climatological data easy, and pretty!

pyClim provides you with a set of Python functions so you can perform a complete analysis of your climatological data with publication-quality figures.

## Install

To install the pyClim package:

```
pip install pyclim
```

## Examples

An example script and a set of example data are provided so you can run the example script and check every kind of figure pyClim can produce. Some of them are shown below:

## Contact

Do you have any questions or suggestions? Have you found a bug? Open an issue or reach out:

Alejandro Rodríguez Sánchez

Email: ars.rodriguezs@gmail.com
